%{
#include <stdio.h>

int yylex(void);
void yyerror(char *);
%}

%token INTEGER
%left '+' '-'
%left '*' '/'
%left UMINUS

%%

program:
	|
	program expr '\n' { printf("%d\n", $2);}
	;
	
expr:
	INTEGER			{ $$ = $1; }
	| '(' expr ')' 	{ $$ = $2; }
	| expr '+' expr { $$ = $1 + $3; }
	| expr '-' expr	{ $$ = $1 - $3; }
	| expr '*' expr	{ $$ = $1 * $3; }
	| expr '/' expr	{ 
						if ($3 == 0) {
							yyerror("division by zero!");
							return -1;
						} else {
							$$ = $1 / $3; 
						}
					}
	| '-' expr %prec UMINUS { $$ = -$2; }
	;
%%

void yyerror(char *s) {
	fprintf(stderr, "%s\n", s);
}

int main(void) {
	yyparse();
	return 0;
}

